Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1264)

Unified Diff: chrome/browser/ui/cocoa/info_bubble_view.h

Issue 2490323002: [Mac] Anchor profile switcher to left side of avatar button in RTL (Closed)
Patch Set: Review comments Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/info_bubble_view.h
diff --git a/chrome/browser/ui/cocoa/info_bubble_view.h b/chrome/browser/ui/cocoa/info_bubble_view.h
index b3b918a0b406acf54d0245e18a0defdf60690b79..09fa4745d458a39c377109d9048d2e046d1f891d 100644
--- a/chrome/browser/ui/cocoa/info_bubble_view.h
+++ b/chrome/browser/ui/cocoa/info_bubble_view.h
@@ -36,10 +36,10 @@ enum BubbleAlignment {
kAlignArrowToAnchor,
// The edge nearest to the arrow is lined up with the anchor point.
kAlignEdgeToAnchorEdge,
- // Align the right edge to the anchor point.
- kAlignRightEdgeToAnchorEdge,
- // Align the left edge to the anchor point.
- kAlignLeftEdgeToAnchorEdge,
+ // Align the trailing edge (right in LTR, left in RTL) to the anchor point.
+ kAlignTrailingEdgeToAnchorEdge,
+ // Align the leading edge (left in LTR, right in RTL) to the anchor point.
+ kAlignLeadingEdgeToAnchorEdge,
};
} // namespace info_bubble
« no previous file with comments | « chrome/browser/ui/cocoa/browser/zoom_bubble_controller.mm ('k') | chrome/browser/ui/cocoa/profiles/avatar_base_controller.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698